# Access Control Systems Library


<p align="left">
<a href="https://pypi.python.org/pypi/acslib">
    <img src="https://img.shields.io/pypi/v/acslib.svg"
        alt = "Release Status">
</a>

<a href="https://github.ncsu.edu/SAT/acslib/actions">
    <img src="https://github.com/jmgibso3/acslib/actions/workflows/main.yml/badge.svg?branch=release" alt="CI Status">
</a>

<a href="https://pyup.io/repos/github/jmgibso3/acslib/">
<img src="https://pyup.io/repos/github/jmgibso3/acslib/shield.svg" alt="Updates">
</a>

A library for interacting with Access Control Systems like Genetec or Ccure9k

</p>



* Free software: MIT
* Documentation: <https://github.com/ncstate-sat/acslib>


## Features

* TODO
